@@ -61,6 +61,20 @@ class BorrowerAPIDTO(BaseModel):
         allow_population_by_field_name = True
         allow_population_by_alias = True
 
+class EntityCategoryValueDTO(BaseModel):
+    category_id: str = Field(alias="categoryId")
+    category_key: str = Field(alias="categoryKey")
+    category_value_id: str = Field(alias="categoryValueId")
+    entity_type: str = Field(alias="entityType")
+    entity_id: str = Field(alias="entityId")
+    created_at: str = Field(alias="createdAt")
+    updated_at: str = Field(alias="updatedAt")
+
+    class Config:
+        populate_by_name = True
+        allow_population_by_field_name = True
+        allow_population_by_alias = True
+
 
 class SimplifiedIdentity(BaseModel):
     id: str = Field(alias="id")
@@ -459,15 +473,22 @@ class BorrowersAsyncModule:
     async def query(self, **kwargs):
         query_params = {}
         for k, v in kwargs.items():
-            if v is not None:
+            if v is not None and k not in ["timeout", "per_page"]:
                 query_params[convert_to_dash_case(k)] = v
 
+        timeout = kwargs.get("timeout", 30)
+        per_page = kwargs.get("per_page", 100)
+        if per_page > 100:
+            logger.warning("per_page is greater than 100, setting it to 100")
+            per_page = 100
+        query_params["per-page"] = per_page
+
         async with httpx.AsyncClient(base_url=self.altscore_client._borrower_central_base_url) as client:
             response = await client.get(
                 f"/v1/borrowers",
                 headers=self.build_headers(),
                 params=query_params,
-                timeout=30
+                timeout=timeout
             )
             raise_for_status_improved(response)
             return [BorrowerAsync(
@@ -501,29 +522,40 @@ class BorrowersAsyncModule:
     @retry_on_401_async
     async def retrieve_all(self, **kwargs):
         query_params = {}
-        per_page = 10
         for k, v in kwargs.items():
             if v is not None:
                 query_params[convert_to_dash_case(k)] = v
+        per_page = kwargs.get("per_page", 100)
+        timeout = kwargs.get("timeout", 30)
+        if per_page > 100:
+            logger.warning("per_page is greater than 100, setting it to 100")
+            per_page = 100
         query_params["per-page"] = per_page
+        clean_kwargs = {k: v for k, v in query_params.items() if v is not None and v not in {"page", "per_page"}}
         async with httpx.AsyncClient(base_url=self.altscore_client._borrower_central_base_url) as client:
             response = await client.get(
                 f"/v1/borrowers",
                 params=query_params,
                 headers=self.build_headers(),
-                timeout=30
+                timeout=timeout
             )
             raise_for_status_improved(response)
             total_count = int(response.headers["x-total-count"])
-        resources = []
-        # TODO: this is not optimal, we should use asyncio.gather and a batch size
+
         total_pages = (total_count // per_page) + 1
         if total_pages > 1:
-            pages = range(1, total_pages + 1)
+            pages = list(range(1, total_pages + 1))
         else:
             pages = [1]
-        for page in pages:
-            resources.append(await self.query(page=page, per_page=per_page, **kwargs))
+
+        resources = []
+        page_chunks = [pages[i:i + 10] for i in range(0, len(pages), 10)]
+
+        for page_chunk in page_chunks:
+            tasks = [self.query(page=page, per_page=per_page, **clean_kwargs) for page in page_chunk]
+            chunk_results = await asyncio.gather(*tasks)
+            resources.extend(chunk_results)
+
         resources = [item for sublist in resources for item in sublist]
         return resources
 
@@ -1300,14 +1332,15 @@ class BorrowerAsync(BorrowerBase):
         return mapped_dict
 
     @retry_on_401_async
-    async def send_sms(self, message: str, point_of_contact_id: Optional[str] = None):
+    async def send_sms(self, message: str, point_of_contact_id: Optional[str] = None, skip_verification_check: Optional[bool] = False):
         async with httpx.AsyncClient(base_url=self.base_url) as client:
             response = await client.post(
                 f"{self.base_url}/v1/borrowers/{self.data.id}/communications/sms",
                 headers=self._header_builder(),
                 json={
                     "message": message,
-                    "pointOfContactId": point_of_contact_id
+                    "pointOfContactId": point_of_contact_id,
+                    "skipVerificationCheck": skip_verification_check
                 }
             )
             raise_for_status_improved(response)
@@ -1326,6 +1359,54 @@ class BorrowerAsync(BorrowerBase):
             raise_for_status_improved(response)
             return None
 
+    @retry_on_401_async
+    async def set_category_value(self, category_key: str, category_value_id: str, inherit_value = False):
+        resource = self.resource
+        if inherit_value:
+            resource += "_ds"
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.post(
+                f"{self.base_url}/v1/category/commands/categorize-entity",
+                headers=self._header_builder(),
+                json={
+                    "categoryKey": category_key,
+                    "categoryValueId": category_value_id,
+                    "entityType": resource,
+                    "entityId": self.data.id
+                }
+            )
+            raise_for_status_improved(response)
+            return None
+
+    @retry_on_401_async
+    async def delete_category_value(self, category_key: str, category_value_id: str):
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.post(
+                f"{self.base_url}/v1/category/commands/delete-entity-category",
+                headers=self._header_builder(),
+                json={
+                    "categoryKey": category_key,
+                    "categoryValueId": category_value_id,
+                    "entityType": self.resource,
+                    "entityId": self.data.id
+                }
+            )
+            raise_for_status_improved(response)
+            return None
+
+    @retry_on_401_async
+    async def get_entity_categories(self):
+        async with httpx.AsyncClient(base_url=self.base_url) as client:
+            response = await client.get(
+                f"{self.base_url}/v1/category/queries/entity/{self.resource}/{self.data.id}",
+                headers=self._header_builder(),
+            )
+            raise_for_status_improved(response)
+            return [
+                EntityCategoryValueDTO.parse_obj(data)
+                for data in response.json()
+            ]
+
     def __str__(self):
         return str(self.data)
 
@@ -1821,14 +1902,15 @@ class BorrowerSync(BorrowerBase):
         return mapped_dict
 
     @retry_on_401
-    def send_sms(self, message: str, point_of_contact_id: Optional[str] = None):
+    def send_sms(self, message: str, point_of_contact_id: Optional[str] = None, skip_verification_check: Optional[bool] = False ):
         with httpx.Client(base_url=self.base_url) as client:
             response = client.post(
                 f"{self.base_url}/v1/borrowers/{self.data.id}/communications/sms",
                 headers=self._header_builder(),
                 json={
                     "message": message,
-                    "pointOfContactId": point_of_contact_id
+                    "pointOfContactId": point_of_contact_id,
+                    "skipVerificationCheck": skip_verification_check
                 }
             )
             raise_for_status_improved(response)
@@ -1847,6 +1929,54 @@ class BorrowerSync(BorrowerBase):
             raise_for_status_improved(response)
             return None
 
+    @retry_on_401
+    def set_category_value(self, category_key: str, category_value_id: str, inherit_value = False):
+        resource = self.resource
+        if inherit_value:
+            resource += "_ds"
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.post(
+                f"{self.base_url}/v1/category/commands/categorize-entity",
+                headers=self._header_builder(),
+                json={
+                    "categoryKey": category_key,
+                    "categoryValueId": category_value_id,
+                    "entityType": resource,
+                    "entityId": self.data.id
+                }
+            )
+            raise_for_status_improved(response)
+            return None
+
+    @retry_on_401
+    def delete_category_value(self, category_key: str, category_value_id: str):
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.post(
+                f"{self.base_url}/v1/category/commands/delete-entity-category",
+                headers=self._header_builder(),
+                json={
+                    "categoryKey": category_key,
+                    "categoryValueId": category_value_id,
+                    "entityType": self.resource,
+                    "entityId": self.data.id
+                }
+            )
+            raise_for_status_improved(response)
+            return None
+
+    @retry_on_401
+    def get_entity_categories(self):
+        with httpx.Client(base_url=self.base_url) as client:
+            response = client.get(
+                f"{self.base_url}/v1/category/queries/entity/{self.resource}/{self.data.id}",
+                headers=self._header_builder(),
+            )
+            raise_for_status_improved(response)
+            return [
+                EntityCategoryValueDTO.parse_obj(data)
+                for data in response.json()
+            ]
+
     def __str__(self):
         return str(self.data)
 
